import "./tasks/novoalign.wdl" as novoalign
import "./tasks/SamToBam.wdl" as SamToBam
import "./tasks/indexBam.wdl" as indexBam
import "./tasks/Metrics.wdl" as Metrics
import "./tasks/Dedup.wdl" as Dedup
import "./tasks/deduped_Metrics.wdl" as deduped_Metrics

workflow {{ project_name }} {

	File fastq_1
	File fastq_2
	File NVref_dir
	File STref_dir

	String index
	String SENTIEON_INSTALL_DIR
	String sample
	String STdocker
	String SAMdocker
	String NVdocker
	String PIdocker
	String fasta
	String disk_size
	String cluster_config

	String id
	String library
	String platform
	String machine

	call novoalign.novoalign as novoalign {
		input: 
		NVref_dir=NVref_dir,
		index=index,
		fastq_1=fastq_1,
		fastq_2=fastq_2,
		NVdocker=NVdocker,
		sample=sample,
		cluster_config=cluster_config,
		disk_size=disk_size
	}

	call SamToBam.SamToBam as SamToBam {
		input:
		aligned_sam=novoalign.aligned_sam,
		sample=sample,
		id=id,
		library=library,
		platform=platform,
		machine=machine, 
		PIdocker=PIdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call indexBam.indexBam as indexBam {
		input: 
		sample=sample,
		sorted_bam=SamToBam.sorted_bam,
		SAMdocker=SAMdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call Metrics.Metrics as Metrics {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		fasta=fasta,
		STref_dir=STref_dir,
		sorted_bam=SamToBam.sorted_bam,
		sorted_bam_index=indexBam.sorted_bam_index,		
		sample=sample,
		STdocker=STdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call Dedup.Dedup as Dedup {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		sorted_bam=SamToBam.sorted_bam,
		sorted_bam_index=indexBam.sorted_bam_index,		
		sample=sample,
		STdocker=STdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	call deduped_Metrics.deduped_Metrics as deduped_Metrics {
		input:
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		fasta=fasta,
		STref_dir=STref_dir,
		Dedup_bam=Dedup.Dedup_bam,
		Dedup_bam_index=Dedup.Dedup_bam_index,
		sample=sample,
		STdocker=STdocker,
		disk_size=disk_size,
		cluster_config=cluster_config
	}

	}

